/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: IDeployerManager.java 2184 2007-12-13 13:24:56Z fornacif $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.deploy.api.deployer;

import org.ow2.util.ee.deploy.api.deployable.IDeployable;

/**
 * Interface of Deployer Manager.
 * @author Florent BENOIT
 */
public interface IDeployerManager {

        /**
         * Register a new Deployer on this manager instance.
         * @param deployer the deployer to register
         */
         void register(final IDeployer deployer);

        /**
         * Unregister a Deployer from this manager instance.
         * @param deployer the given deployer to unregister.
         */
         void unregister(final IDeployer deployer);

        /**
         * Deploy a given deployable by finding the first deployer that accept
         * this type of deployable.
         * @param deployable the given deployable to deploy.
         * @throws DeployerException if it cannot be undeployed.
         * @throws UnsupportedDeployerException if no deployer is found for the given deployable.
         */
        void deploy(IDeployable<?> deployable) throws DeployerException, UnsupportedDeployerException;

        /**
         * Undeploy a given deployable by finding the first deployer that accept
         * this type of deployable.
         * @param deployable the given deployable to undeploy.
         * @throws DeployerException if it cannot be undeployed.
         * @throws UnsupportedDeployerException if no deployer is found for the given deployable.
         */
         void undeploy(IDeployable<?> deployable) throws DeployerException, UnsupportedDeployerException;


        /**
         * Deploy a given deployable by finding the first deployer that accept
         * this type of deployable.
         * @param deployable the given deployable to deploy.
         * @throws DeployerException if it cannot be undeployed.
         * @throws UnsupportedDeployerException if no deployer is found for the given deployable.
         */
        void isDeployed(IDeployable<?> deployable) throws DeployerException, UnsupportedDeployerException;

}

